==> jc-1.4.0.tar.gz: java/awt/print/PrinterIOException.h <==
// public class java.awt.print.PrinterIOException

// class file dependencies
// @dep_class edcbe23a737fb84b java_awt_print_PrinterException
// @dep_class 167947e657a64228 java_awt_print_PrinterIOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_awt_print_PrinterException

#include "java/awt/print/PrinterException.h"

#ifndef _JC_java_awt_print_PrinterIOException_H_
#define _JC_java_awt_print_PrinterIOException_H_

// Forward structure declarations
struct _jc_java_io_IOException$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Throwable$object;

// Typedefs
typedef struct _jc_java_awt_print_PrinterIOException$sub_refs	_jc_java_awt_print_PrinterIOException$sub_refs;
typedef struct _jc_java_awt_print_PrinterIOException$sub_nonrefs	_jc_java_awt_print_PrinterIOException$sub_nonrefs;
typedef struct _jc_java_awt_print_PrinterIOException$refs	_jc_java_awt_print_PrinterIOException$refs;
typedef struct _jc_java_awt_print_PrinterIOException$nonrefs	_jc_java_awt_print_PrinterIOException$nonrefs;
typedef struct _jc_java_awt_print_PrinterIOException$object	_jc_java_awt_print_PrinterIOException$object;

typedef struct _jc_java_awt_print_PrinterIOException$fields_struct	_jc_java_awt_print_PrinterIOException$fields_struct;
typedef const struct _jc_java_awt_print_PrinterIOException$vmethods	_jc_java_awt_print_PrinterIOException$vmethods;
typedef const struct _jc_java_awt_print_PrinterIOException$vtable	_jc_java_awt_print_PrinterIOException$vtable;
typedef const struct _jc_java_awt_print_PrinterIOException$vtype	_jc_java_awt_print_PrinterIOException$vtype;

// Class fields structure
struct _jc_java_awt_print_PrinterIOException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_print_PrinterIOException$fields_struct _jc_java_awt_print_PrinterIOException$class_fields;

// Constructors
extern void _jc_java_awt_print_PrinterIOException$method$_init$d482075feb0ad350(_jc_env *, struct _jc_java_awt_print_PrinterIOException$object *, struct _jc_java_io_IOException$object *);

// Virtual methods
extern struct _jc_java_lang_Throwable$object *_jc_java_awt_print_PrinterIOException$method$getCause$d5a96efc8523817a(_jc_env *, struct _jc_java_awt_print_PrinterIOException$object *);
extern struct _jc_java_io_IOException$object *_jc_java_awt_print_PrinterIOException$method$getIOException$d849cb50b9ab6cf9(_jc_env *, struct _jc_java_awt_print_PrinterIOException$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_print_PrinterIOException$method_info$getCause$d5a96efc8523817a;
extern _jc_method _jc_java_awt_print_PrinterIOException$method_info$getIOException$d849cb50b9ab6cf9;

// Virtual methods structure
struct _jc_java_awt_print_PrinterIOException$vmethods {
	struct _jc_java_lang_Throwable$object	*(*getCause$d5a96efc8523817a)(_jc_env *, struct _jc_java_awt_print_PrinterIOException$object *);
	struct _jc_java_io_IOException$object	*(*getIOException$d849cb50b9ab6cf9)(_jc_env *, struct _jc_java_awt_print_PrinterIOException$object *);
};

// Vtable
struct _jc_java_awt_print_PrinterIOException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_awt_print_PrinterException$vmethods	java_awt_print_PrinterException;
	_jc_java_awt_print_PrinterIOException$vmethods	java_awt_print_PrinterIOException;
};

// Vtype
struct _jc_java_awt_print_PrinterIOException$vtype {
	_jc_type			type;
	_jc_java_awt_print_PrinterIOException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_print_PrinterIOException$sub_refs {
	struct _jc_java_io_IOException$object	*mException;
};

// Reference instance fields (object)
struct _jc_java_awt_print_PrinterIOException$refs {
    _jc_java_awt_print_PrinterIOException$sub_refs	java_awt_print_PrinterIOException;
    _jc_java_awt_print_PrinterException$sub_refs	java_awt_print_PrinterException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_print_PrinterIOException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_print_PrinterIOException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_awt_print_PrinterException$sub_nonrefs	java_awt_print_PrinterException;
    _jc_java_awt_print_PrinterIOException$sub_nonrefs	java_awt_print_PrinterIOException;
};

// Object instance structure
struct _jc_java_awt_print_PrinterIOException$object {
	_jc_java_awt_print_PrinterIOException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_print_PrinterIOException$vtype	*vtype;
	_jc_java_awt_print_PrinterIOException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_print_PrinterIOException$vtype _jc_java_awt_print_PrinterIOException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_print_PrinterIOException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_print_PrinterIOException$class_object;

#endif	/* _JC_java_awt_print_PrinterIOException_H_ */

==> jc-1.4.6.tar.gz: java/awt/print/PrinterIOException.h <==
// public class java.awt.print.PrinterIOException

// class file dependencies
// @dep_class edcbe23a737fb84b java_awt_print_PrinterException
// @dep_class 167947e657a64228 java_awt_print_PrinterIOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_awt_print_PrinterException

#include "java/awt/print/PrinterException.h"

#ifndef _JC_java_awt_print_PrinterIOException_H_
#define _JC_java_awt_print_PrinterIOException_H_

// Forward structure declarations
struct _jc_java_io_IOException$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Throwable$object;

// Typedefs
typedef struct _jc_java_awt_print_PrinterIOException$sub_refs	_jc_java_awt_print_PrinterIOException$sub_refs;
typedef struct _jc_java_awt_print_PrinterIOException$sub_nonrefs	_jc_java_awt_print_PrinterIOException$sub_nonrefs;
typedef struct _jc_java_awt_print_PrinterIOException$refs	_jc_java_awt_print_PrinterIOException$refs;
typedef struct _jc_java_awt_print_PrinterIOException$nonrefs	_jc_java_awt_print_PrinterIOException$nonrefs;
typedef struct _jc_java_awt_print_PrinterIOException$object	_jc_java_awt_print_PrinterIOException$object;

typedef struct _jc_java_awt_print_PrinterIOException$fields_struct	_jc_java_awt_print_PrinterIOException$fields_struct;
typedef const struct _jc_java_awt_print_PrinterIOException$vmethods	_jc_java_awt_print_PrinterIOException$vmethods;
typedef const struct _jc_java_awt_print_PrinterIOException$vtable	_jc_java_awt_print_PrinterIOException$vtable;
typedef const struct _jc_java_awt_print_PrinterIOException$vtype	_jc_java_awt_print_PrinterIOException$vtype;

// Class fields structure
struct _jc_java_awt_print_PrinterIOException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_print_PrinterIOException$fields_struct _jc_java_awt_print_PrinterIOException$class_fields;

// Constructors
extern void _jc_java_awt_print_PrinterIOException$method$_init$d482075feb0ad350(_jc_env *, struct _jc_java_awt_print_PrinterIOException$object *, struct _jc_java_io_IOException$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Throwable$object *_jc_java_awt_print_PrinterIOException$method$getCause$d5a96efc8523817a(_jc_env *, struct _jc_java_awt_print_PrinterIOException$object *) _JC_JCNI_ATTR;
extern struct _jc_java_io_IOException$object *_jc_java_awt_print_PrinterIOException$method$getIOException$d849cb50b9ab6cf9(_jc_env *, struct _jc_java_awt_print_PrinterIOException$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_print_PrinterIOException$method_info$getCause$d5a96efc8523817a;
extern _jc_method _jc_java_awt_print_PrinterIOException$method_info$getIOException$d849cb50b9ab6cf9;

// Virtual methods structure
struct _jc_java_awt_print_PrinterIOException$vmethods {
	struct _jc_java_lang_Throwable$object	*(*getCause$d5a96efc8523817a)(_jc_env *, struct _jc_java_awt_print_PrinterIOException$object *) _JC_JCNI_ATTR;
	struct _jc_java_io_IOException$object	*(*getIOException$d849cb50b9ab6cf9)(_jc_env *, struct _jc_java_awt_print_PrinterIOException$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_print_PrinterIOException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_awt_print_PrinterException$vmethods	java_awt_print_PrinterException;
	_jc_java_awt_print_PrinterIOException$vmethods	java_awt_print_PrinterIOException;
};

// Vtype
struct _jc_java_awt_print_PrinterIOException$vtype {
	_jc_type			type;
	_jc_java_awt_print_PrinterIOException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_print_PrinterIOException$sub_refs {
	struct _jc_java_io_IOException$object	*mException;
};

// Reference instance fields (object)
struct _jc_java_awt_print_PrinterIOException$refs {
    _jc_java_awt_print_PrinterIOException$sub_refs	java_awt_print_PrinterIOException;
    _jc_java_awt_print_PrinterException$sub_refs	java_awt_print_PrinterException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_print_PrinterIOException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_print_PrinterIOException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_awt_print_PrinterException$sub_nonrefs	java_awt_print_PrinterException;
    _jc_java_awt_print_PrinterIOException$sub_nonrefs	java_awt_print_PrinterIOException;
};

// Object instance structure
struct _jc_java_awt_print_PrinterIOException$object {
	_jc_java_awt_print_PrinterIOException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_print_PrinterIOException$vtype	*vtype;
	_jc_java_awt_print_PrinterIOException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_print_PrinterIOException$vtype _jc_java_awt_print_PrinterIOException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_print_PrinterIOException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_print_PrinterIOException$class_object;

#endif	/* _JC_java_awt_print_PrinterIOException_H_ */
